Potential Features
------------------

* callLater which runs code in thread pool.
* LoopingCall which runs code in thread pool.
* Notice reactor is already being run by someone else, e.g. Twisted being used
  as WSGI container? or maybe no_setup().
* Poll for dead processes.

